/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_apoint_h__
#define __glass_apoint_h__

/* The update mode on the active point */
enum _GlassAPointUpdate
{
  GLASS_UPDATE_NONE = 0,
  /* Active point is updated every time model is drawn */
  GLASS_UPDATE_CONTINUOUS,
  /* Active point is updated only when value is retrieved */
  GLASS_UPDATE_DEMAND
};

typedef enum _GlassAPointUpdate GlassAPointUpdate;
typedef struct _GlassActivePoint GlassActivePoint;

#include "global.h"

/* A point on a node, whose absolute position and direction can be retrieved */
struct _GlassActivePoint
{
  char *name;

  GLfloat pos[3];
  GLfloat dir[3];
  GLfloat initial_dir[3];

  GlassAPointUpdate update;

  GlassActivePoint *next;
};

/* Make a new active point */
GlassActivePoint *_glassActivePointNew(void);

/* Set the active point's name */
void _glassActivePointSetName(GlassActivePoint *apoint, const char *name);

/* Get the active point's name */
const char *_glassActivePointGetName(GlassActivePoint *apoint);

/* Set the initial direction of the active point */
void _glassActivePointSetInitDir(GlassActivePoint *apoint, GLfloat dx, GLfloat dy, GLfloat dz);

/* Set the initial direction of the active point with an array (vector) */
void _glassActivePointSetInitDirv(GlassActivePoint *apoint, GLfloat *dir);

/* Get the initial direction of the active point */
GLfloat *_glassActivePointGetInitDir(GlassActivePoint *apoint);

/* Get the current position  of the active point */
GLfloat *_glassActivePointGetPos(GlassActivePoint *apoint);

/* Get the current direction of the active point */
GLfloat *_glassActivePointGetDir(GlassActivePoint *apoint);

/* Update the position, and direction of the active point by using the current
   openGL modelview matrix */
void _glassActivePointUpdate(GlassActivePoint *apoint);

/* Free the active point */
void _glassFreeActivePoint(GlassActivePoint *apoint);

#endif /* __glass_apoint_h__ */
