/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_material_h__
#define __glass_material_h__

typedef struct _GlassMaterial GlassMaterial;

#include "global.h"
#include "glass_texture.h"

/* A triangles material */
struct _GlassMaterial
{
  char *name;
  int is_alpha;
  GLfloat ambient[4], diffuse[4], specular[4], emission[4], shininess;
  GlassTexture *texture;

  GlassMaterial *next;

  /* Load data */
  void *ad;
};

/* Make a material */
GlassMaterial *_glassMaterialNew(void);

/* Set the material's name */
void _glassMaterialSetName(GlassMaterial *material, const char *name);

/* Get the material's name */
const char *_glassMaterialGetName(GlassMaterial *material);

/* Set the ambient colour of the material */
void _glassMaterialSetAmbient(GlassMaterial *material,
			      GLfloat r, GLfloat g, GLfloat b, GLfloat a);

/* Set the ambient colour of the material with an array (vector) */
void _glassMaterialSetAmbientv(GlassMaterial *material,
			       GLfloat *ambient);

/* Set the diffuse colour of the material */
void _glassMaterialSetDiffuse(GlassMaterial *material,
			      GLfloat r, GLfloat g, GLfloat b, GLfloat a);

/* Set the diffuse colour of the material with an array (vector) */
void _glassMaterialSetDiffusev(GlassMaterial *material,
			       GLfloat *diffuse);

/* Set the specular reflectance of the material */
void _glassMaterialSetSpecular(GlassMaterial *material,
			       GLfloat r,  GLfloat g,  GLfloat b, GLfloat a);

/* Set the specular reflectance of the material with an array (vector) */
void _glassMaterialSetSpecularv(GlassMaterial *material,
				GLfloat *specular);

/* Set the emmitted colour of the material */
void _glassMaterialSetEmission(GlassMaterial *material,
			       GLfloat r, GLfloat g, GLfloat b, GLfloat a);

/* Set the emmitted colour of the material with an array (vector) */
void _glassMaterialSetEmissionv(GlassMaterial *material,
				GLfloat *emission);

/* Set the shininess of the material */
void _glassMaterialSetShininess(GlassMaterial *material, GLfloat shininess);

/* Set the texture of the material */
void _glassMaterialSetTexture(GlassMaterial *material, GlassTexture *texture);

/* Get the texture of the material */
GlassTexture *_glassMaterialGetTexture(GlassMaterial *material);

/* Free the material */
void _glassFreeMaterial(GlassMaterial *material);

#endif /* __glass_material_h__ */
