/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_model_h__
#define __glass_model_h__

typedef struct _GlassModel GlassModel;

#include "global.h"
#include "glass_library.h"
#include "glass_texture.h"
#include "glass_material.h"
#include "glass_variable.h"
#include "glass_surface.h"
#include "glass_apoint.h"
#include "glass_node.h"

/* A GLASS model */
struct _GlassModel
{
  char *name;
  GlassLibrary *library;

  int nsurfaces, nvariables, npoints;
  GlassVariable **variable_array;
  GlassSurface **surface_array;
  GlassActivePoint **apoint_array;

  int variables_changed;

  GlassTexture *textures, *last_texture;
  GlassMaterial *materials, *last_material;
  GlassVariable *variables, *last_variable;
  GlassSurface *surfaces, *last_surface;
  GlassActivePoint *apoints, *last_apoint;
  GlassNode *children, *last_child;
};

/* Returns an empty model */
GlassModel *_glassModelNew(const char *name);

/* Set the model's name */
void _glassModelSetName(GlassModel *model, const char *name);

/* Get the model's name */
const char *_glassModelGetName(GlassModel *model);

/* Add a texture into the model */
void _glassModelAddTexture(GlassModel *model, GlassTexture *texture);

/* Find a texture with the name `name', return NULL if not found */
GlassTexture *_glassModelFindTexture(GlassModel *model, const char *name);

/* Add a material into the model */
void _glassModelAddMaterial(GlassModel *model, GlassMaterial *material);

/* Find a material with the name `name', return NULL if not found */
GlassMaterial *_glassModelFindMaterial(GlassModel *model, const char *name);

/* Add a surface into the model */
void _glassModelAddSurface(GlassModel *model, GlassSurface *surface);

/* Find a surface with the name `name', return NULL if not found */
GlassSurface *_glassModelFindSurface(GlassModel *model, const char *name);

/* Add a variable into the model */
void _glassModelAddVariable(GlassModel *model, GlassVariable *variable);

/* Find a variable with the name `name', return NULL if not found */
GlassVariable *_glassModelFindVariable(GlassModel *model, const char *name);

/* Add an active point into the model */
void _glassModelAddActivePoint(GlassModel *model, GlassActivePoint *apoint);

/* Find a active point with the name `name', return NULL if not found */
GlassActivePoint *_glassModelFindActivePoint(GlassModel *model, const char *name);

/* Add a child node to the model */
void _glassModelAddChild(GlassModel *model, GlassNode *node);

/* (Re)Build both the variable and surface arrays */
void _glassModelBuildArrays(GlassModel *model);

/* Go through the model and update the active points by doing the transforms */
void _glassModelUpdateActivePoints(GlassModel *model);

/* Convert as many surfaces as possible into openGL display lists */
void _glassModelMakeDisplayLists(GlassModel *model);

/* Free an model */
void _glassFreeModel(GlassModel *model);

#endif /* __glass_model_h__ */
