/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_triangle_h__
#define __glass_triangle_h__

typedef struct _GlassTriangle GlassTriangle;

#include "global.h"
#include "glass_surface.h"
#include "glass_material.h"

/* A triangle */
struct _GlassTriangle
{
  int is_alpha;

  GLfloat pos[3][3], col[3][4], nor[3][3], tex[3][2];
  GlassMaterial *material;

  GlassTriangle *next;

  /* Load data */
  void *ad;
};

/* Returns an empty triangle */
GlassTriangle *_glassTriangleNew(GlassSurface *surface);

/* Set the position for a triangles vertex */
void _glassTriangleSetPosition(GlassTriangle *triangle, int vertex, GLfloat *pos);

/* Get the position of a triangles vertex */
GLfloat *_glassTriangleGetPosition(GlassTriangle *triangle, int vertex);

/* Set the colour for a triangles vertex */
void _glassTriangleSetColour(GlassTriangle *triangle, int vertex, GLfloat *col);

/* Get the colour of a triangles vertex */
GLfloat *_glassTriangleGetColour(GlassTriangle *triangle, int vertex);

/* Set the normal for a triangles vertex */
void _glassTriangleSetNormal(GlassTriangle *triangle, int vertex, GLfloat *nor);

/* Get the normal of a triangles vertex */
GLfloat *_glassTriangleGetNormal(GlassTriangle *triangle, int vertex);

/* Set the texture co-ordinates for a triangles vertex */
void _glassTriangleSetTexCoord(GlassTriangle *triangle, int vertex, GLfloat *tex);

/* Get the texture co-ordinate of a triangles vertex */
GLfloat *_glassTriangleGetTexCoord(GlassTriangle *triangle, int vertex);

/* Set the material of the triangle */
void _glassTriangleSetMaterial(GlassTriangle *triangle, GlassMaterial *material);

/* Get the material of a triangle */
GlassMaterial *_glassTriangleGetMaterial(GlassTriangle *triangle);

/* Free a triangle */
void _glassFreeTriangle(GlassTriangle *triangle);

#endif /* __glass_triangle_h__ */
