/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_variable_h__
#define __glass_variable_h__

typedef struct _GlassVariable GlassVariable;

#include "global.h"

/* A bounded value, that controls a transform */
struct _GlassVariable
{
  char *name;

  GLfloat value, min, max;
  GlassVariable *next;
};

/* Returns an empty variable */
GlassVariable *_glassVariableNew(const char *name, GLfloat min, GLfloat max, GLfloat value);

/* Set the variables name */
void _glassVariableSetName(GlassVariable *variable, const char *name);

/* Set the variables name */
const char *_glassVariableGetName(GlassVariable *variable);

/* Set the value of a variable */
void _glassVariableSetValue(GlassVariable *variable, GLfloat value);

/* Increment the value of a variable */
void _glassVariableIncValue(GlassVariable *variable, GLfloat dvalue);

/* Get the value of a variable */
GLfloat _glassVariableGetValue(GlassVariable *variable);

/* Get a pointer to the value of a variable */
const GLfloat *_glassVariableGetValuev(GlassVariable *variable);

/* Set the minimum of a variable */
void _glassVariableSetMin(GlassVariable *variable, GLfloat min);

/* Get the minimum of a variable */
GLfloat _glassVariableGetMin(GlassVariable *variable);

/* Set the max of a variable */
void _glassVariableSetMax(GlassVariable *variable, GLfloat max);

/* Get the maximum of a variable */
GLfloat _glassVariableGetMax(GlassVariable *variable);

/* Free a variable */
void _glassFreeVariable(GlassVariable *variable);

#endif /* __glass_variable_h__ */
